@@ -20,7 +20,9 @@ class BaseFormatter(object):
         self.util = util
         self._title = title
         self._groupid = 1
-        self.output_summary = False
+        self.output_summary = True
+        self.output_resubmit_loop = True
+        self.output_target_tables = []
         self.util.debug_out(self.formatter_name + " formatter initialized")
 
     def format(self):
@@ -37,6 +39,12 @@ class BaseFormatter(object):
     def set_tables(self, tables):
         self._tables = tables
 
+    def set_output_target_tables(self, output_target_tables):
+        if output_target_tables is not None:
+            self.output_target_tables = output_target_tables
+
     def set_output_summary(self, output_summary):
         self.output_summary = output_summary
-        
\ No newline at end of file
+
+    def set_output_resubmit_loop(self, output_resubmit_loop):
+        self.output_resubmit_loop = output_resubmit_loop
