@@ -54,9 +54,9 @@ class GraphvizTBFormatter(BaseFormatter):
     HEADER_FORMAT = '''
 digraph GRAPH_0 {
 
-edge [ dirType="forward", arrowtail=none, fontsize=10, ];
+edge [ dirType="forward", arrowtail=none, fontsize=10, fontname="Arial" ];
 ratio = "auto"
-graph [ label="", rankdir=TB, concentrate=true, compound=true ];
+graph [ label="", rankdir=TB, fontsize=22, fontname="Arial", concentrate=true, compound=true ];
 node [
     fontsize=12,
     fillcolor=white,
@@ -80,7 +80,8 @@ node [
   subgraph cluster_t${table_no} {
     label="Table ${table_no}";
     color="#000000";
-    style=dotted;
+    style=dashed;
+    penwidth=2;
     """
     
     TABLE_END = '  }'
@@ -90,7 +91,8 @@ node [
       label="Priority ${priority_no}";
       labeljust = "l";
       color="#cc0000";
-      style=dotted;
+      style=dashed;
+      penwidth=2;
     """
 
     PRIORITY_END = '    }'
@@ -361,7 +363,7 @@ node [
         self.util.debug_out("TARGET INSTRUCTION: " + str(instructions))
         instruction_set = self._split_instruction(instructions)
         for actions in instruction_set:
-            if re.match(r'.* output:.*', actions) is not None or re.match(r'.* LOCAL.*', actions) is not None:
+            if re.match(r'.* output:.*', actions) is not None or re.match(r'.* ALL.*', actions) is not None or re.match(r'.* NORMAL.*', actions) is not None or re.match(r'.* LOCAL.*', actions) is not None:
                 formatted_str += "\n" + self.INDENT_IN_PRIORITY_BLOCK + \
                     self._format_instruction_output(table_no, priority_no, entry_no, instruction_no, actions)
             elif re.match(r'.* CONTROLLER:.*', actions) is not None:
@@ -515,7 +517,7 @@ node [
             self.util.debug_out("i_no:  " + str(instruction_no) + ": " + inst)
             instruction_set[instruction_no] += "<f" + str(
                 f_no) + "> " + inst + "|"
-            if inst.startswith("resubmit") or inst.startswith("goto_table:") or inst.startswith("output:") or inst.startswith("LOCAL") or inst.startswith("CONTROLLER:"):
+            if inst.startswith("resubmit") or inst.startswith("goto_table:") or inst.startswith("output:") or inst.startswith("ALL") or inst.startswith("LOCAL") or inst.startswith("NORMAL") or inst.startswith("CONTROLLER:"):
                 if action_no < (len(instructions) - 1):
                     instruction_no += 1
                     instruction_set.append("")
